Bibliography
============

.. [BAMTOOLS] https://github.com/pezmaster31/bamtools

.. [BCFTOOLS] http://www.htslib.org/doc/bcftools.html

.. [BEDTOOLS] BEDTools: a flexible suite of utilities for comparing genomic features
   Aaron R. quinlan, Ira M. Hall 2010 Bioinformatics 26(6) 
   https://doi.org/10.1093/bioinformatics/btq033

.. [BIOPYTHON] Biopython: freely available Python tools for computational molecular biology
    and bioinformatics. Cock et al 2009, Bioinformatics 25(11) 
    https://doi.org/10.1093/bioinformatics/btp163

.. [DEEPTOOLS] Ramírez, Fidel, Devon P. Ryan, Björn Grüning, Vivek Bhardwaj,
    Fabian Kilpert, Andreas S. Richter, Steffen Heyne, Friederike Dündar, and
    Thomas Manke. “deepTools2: a next generation web server for deep-sequencing data
    analysis.” Nucleic Acids Research (2016): gkw257.

.. [DSRC] https://github.com/refresh-bio/DSRC

.. [GOALIGN] https://github.com/evolbioinfo/goalign

.. [GOTREE] https://github.com/evolbioinfo/gotree

.. [MOSDEPTH] Mosdepth: quick coverage calculation for genomes and exomes
      Brent S Pedersen, Aaron R Quinlan 2018 Bioinformatics, 34(5) 
      https://doi.org/10.1093/bioinformatics/btx699

.. [PANDAS] Wes McKinney. Data Structures for Statistical Computing in Python,
   Proceedings of the 9th Python in Science Conference, 51-56 (2010) 

.. [PIGZ] https://zlib.net/pigz/

.. [PLINK] http://zzz.bwh.harvard.edu/plink/

.. [PYEXCEL] http://docs.pyexcel.org/en/latest/

.. [PYSAM] The Sequence Alignment/Map format and SAMtools. Li H, Handsaker B,
   Wysoker A, Fennell T, Ruan J, Homer N, Marth G, Abecasis G, Durbin R; 1000
   Genome Project Data Processing Subgroup. Bioinformatics. 2009 Aug
   15;25(16):2078-9. Epub 2009 Jun 8. PMID: 19505943

.. [SAMBAMBA] https://lomereiter.github.io/sambamba/

.. [SAMTOBAM] Ogasawara T, Cheng Y, Tzeng T-HK (2016) Sam2bam:
     High-Performance Framework for NGS Data Preprocessing Tools. PLoS ONE
     11(11): e0167100. doi:10.1371/journal.pone.0167100

.. [SAMTOOLS] Li H, Handsaker B, Wysoker A, Fennell T, Ruan J, Homer N, Marth G,
    Abecasis G, Durbin R, and 1000 Genome Project Data Processing Subgroup, The
    Sequence alignment/map (SAM) format and SAMtools, Bioinformatics (2009) 25(16)
    2078-9 [19505943]

.. [SQUIZZ] ftp://ftp.pasteur.fr/pub/gensoft/projects/squizz/

.. [UCSC] https://genome.ucsc.edu/util.html

.. [WIGGLETOOLS] Zerbino DR, Johnson N, Juettemann T, Wilder SP and Flicek PR:
   WiggleTools: parallel processing of large collections of genome-wide datasets
   for visualization and statistical analysis. Bioinformatics 2014 30:1008-1009.


